"""Top-level package for CellarTracker."""

__author__ = """Mathieu Rul"""
__email__ = 'mathieu.rul@gmail.com'
__version__ = '1.0.0'
